#
# spec file for package dd_rescue
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dd_rescue
Version:        1.40
Release:        6.3
Summary:        Data Copying in the Presence of I/O Errors
License:        GPL-2.0 or GPL-3.0
Group:          System/Base
Url:            http://www.garloff.de/kurt/linux/ddrescue/
Source0:        http://garloff.de/kurt/linux/ddrescue/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  libattr-devel
BuildRequires:  libfallocate-devel
Requires:       bc
Recommends:     dd_rhelp libfallocate0
# ddrescue was last used in openSUSE 11.4 (version 1.14_0.0.6)
Provides:       ddrescue = %{version}
Obsoletes:      ddrescue < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
dd_rescue helps when nothing else can: your disk has crashed and you
try to copy it over to another one. While standard Unix tools like cp,
cat, and dd will "abort" on every I/O error, dd_rescue does not.

dd_rescue has many other goodies; optimization by using large blocks
as long as no errors are in sight and falling back to small ones; reverse
direction copy; splice in-kernel zerocopy; O_DIRECT support; preallocation
with fallocate(); random number writing etc.

%prep
%setup -q -n dd_rescue

# Remove build time references so build-compare can do its work
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__TIME__/\"$FAKE_BUILDTIME\"/g" dd_rescue.c
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/g" dd_rescue.c

%build
make RPM_OPT_FLAGS="%{optflags}" LIBDIR=%{_libdir} %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} INSTALLDIR=%{buildroot}/%{_bindir} \
    INSTASROOT= INSTALLFLAGS=

#UsrMerge
mkdir %{buildroot}/bin
ln -sf %{_bindir}/dd_rescue %{buildroot}/bin
#EndUsrMerge

%check
make check

%files
%defattr(-,root,root,-)
%doc COPYING README.dd_rescue
%{_bindir}/dd_rescue
#UsrMerge
/bin/dd_rescue
#EndUsrMerge
%doc %{_mandir}/man1/dd_rescue.1%{ext_man}

%changelog
* Sun Aug 18 2013 kurt@garloff.de
- Update to dd_rescue-1.40:
  * Copy xattrs on -p/--preserve
  * For odd file offsets, do odd-sized write first, so subsequent
    writes are aligned.
  * Support half-empty block sparse detection and double softbs
    default for buffered IO.
  * Add a lot more test cases to make check.
* Thu Aug  8 2013 kurt@garloff.de
- Update to dd_rescue-1.39:
  * Fix an issue with the last block being appended zeros if
    hardbs==softbs (bnc #833765).
  * A little ARM asm speedup (~15%%) for sparse detection.
  * Clarify help/man page w.r.t. interpretation of -y/--syncfreq.
  * We use autoconf for feature detection now.
- Build version with libdl by default now.
* Fri Aug  2 2013 kurt@garloff.de
- Update to dd_rescue-1.38:
  * Further optimized SSE2 sparse detection. (Also added AVX2
    version, not enabled by default though.)
  * --force allows to ignore non-seekable output with non zero
    output position.
  * make check does some testing ...
  * improved cur.rate and ETA calculation.
* Thu Aug  1 2013 kurt@garloff.de
- Update to dd_rescue-1.37:
  * Important bugfix for SSE2 sparse detection.
  * Fix exact zero-length on big endian machines (irrelevant).
* Wed Jul 24 2013 kurt@garloff.de
- Update to dd_rescue-1.36:
  * Fix overflow with avg.load display
  * Enable SSE2 on (32bit)x86 with runtime detection
  * Add optimized zero block detection on ARM (3x faster with asm ...)
* Wed Jul 17 2013 kurt@garloff.de
- Update to dd_rescue-1.35:
  * Better readability for reports with (optional) colors and rate
    limitation on progress updates.
  * Simple rewrite logic.
  * SSE2 optimized version for finding zero blocks (sparse detection).
* Sun Jul  7 2013 asterios.dramis@gmail.com
- Update to version 1.34:
  * Better support for various *nix systems (specifically has a few fixes for
    FreeBSD).
  * Better compatibility with compilers (clang and g++ and clang++).
  * It can now also load libfallocate at runtime (libdl).
  * Detects a few more fatal write errors as such.
* Sun May 26 2013 asterios.dramis@gmail.com
- Update to version 1.33:
  * Long options
  * New double overwrite mode (-2)
  * Man page added
* Mon Feb 11 2013 kurt@garloff.de
- Update to dd_rescue-1.32:
  * New option -x to append to outfile.
  * New option -Y (can be used multiple times) to specify 2ndary
    output files.
* Sun Feb  3 2013 kurt@garloff.de
- Update to dd_rescue-1.31:
  * Some minor output cleanups.
  * Implementation of safe triple overwrite (options -3 and -4)
    following BSI GSDS M7.15.
- Update to dd_rescue-1.30:
  * Fix issue with double free (1.29)
  * Fix output to stdout ("-")
  * Rationalize messages a bit.
  * Option to init PRNG from file (e.g. -Z /dev/urandom)
  * Option -W to avoid writes (if output block is identical)
- Update to dd_rescue-1.29:
  * Correctly handle last bytes before EOF when hardbs == softbs.
  * New option -M (dont extend output file).
  * New option -R (repeated output of one block, auto for dev/zero)
  * New options -z x, -Z x to use userspace pseudo RNG to overwrite
    disks / files with random data.
* Sat May 26 2012 zaitor@opensuse.org
- Update to version 1.28:
  * Better defaults for hard and softblock sizes (4k/64k for
    buffered I/O, 512/1M for direct IO).
  * Copying of access times with the option -p fixed.
* Sat May 19 2012 asterios.dramis@gmail.com
- Update to version 1.27:
  * Allow to do 512b direct IO (which is possible in latest Linux kernels).
    Change posix_memalign() variable assignment. It has a number of fixes; most
    importantly, when exiting because of an error, it updates the variables
    that are output. dd_rescue now avoids special characters in the logfile. It
    handles situations gracefully, where wrong positions resulted in the
    progress graph causing faults. Some come from illegal input (negative
    offset ...), which is now detected.
* Mon Mar 12 2012 asterios.dramis@gmail.com
- Update to version 1.25:
  * Fix for spurious "Success" messages that resulted from overwritten
    (cleared) errno. Bad blocks are formatted in a way that they are not
    overwritten on screen and block numbers are output as unsigned.
- Removed dd_rhelp from the package (dd_rhelp will become a separate package. A
  recommended entry for dd_rhelp was added in dd_rescue).
- Spec file updates:
  * Updated License: to "GPL-2.0 or GPL-3.0".
  * Removed bc from BuildRequires: (not needed since dd_rhelp was removed).
* Tue Feb  7 2012 rschweikert@suse.com
- place binaries in /usr tree (UsrMerge project)
* Wed Oct  5 2011 garloff@suse.de
- Update to dd_rescue-1.24:
  * Handle directory as output filename (append input basename).
- Fix dd_rhelp.test script and add to %%check.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Sat Sep  3 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changed License: to GPL-2.0 (bnc#714914).
  * Minor other updates.
* Sat May 14 2011 asterios.dramis@gmail.com
- Update to dd_rhelp-0.1.2:
  * IMPROVEMENT : will check the log file destination for sane conditions and
    will try some other locations if not.
  * IMPROVEMENT : will manage max_err parameter to avoid creating to much
    chunks.
  * More and better information displayed at 'info' time.
  From dd_rhelp-0.1.0:
  * INSTALL : No more ./configure && make && make install ... all detection
    were done at runtime anyway
  * UPDATE : updated libs provided in dd_rhelp
  * UPDATE : finally compatible with recent tail/head "-n" arguments
  * Added some sanity tests.
  * TEST : Started to create dd_rhelp.test which unit tests dd_rhelp.
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Added description for the patches based on openSUSE Patches Guidelines.
  * Added a fix inside the spec file to remove build time references
  * dd_rhelp no longer needs auto* tools.
  * Minor other updates.
- Removed dd_rhelp_src.diff patch (fixed upstream).
- Rebased the other patches to apply cleanly.
* Wed Nov  3 2010 garloff@suse.de
- Move autoconf/configure stuff to %%build section.
* Thu Oct 14 2010 garloff@suse.de
- Adapt BuildRequires to new naming of libfallocate-devel-static.
* Mon Oct 11 2010 garloff@suse.de
- dd_rescue-1.23:
  * A short read (because of EOF) is not regarded an error anymore.
    This fixes confusing exit codes as well as non-quietness for -q.
  * We now REALLY default to -y0.
* Thu Sep  9 2010 garloff@suse.de
- dd_rescue-1.22:
  * Display compiler, compile time, enabled options.
  * If hardbs == softbs, don't repeat copy attempts.
  * Fix FPE in progress bar for non-seekable input reverse copy.
  * Document some of the goodies in the README.
  * Make code more digestable for non-GCC compilers, optional
    fallbacks for strsignal, pread, pwrite.
* Mon Aug 30 2010 garloff@suse.de
- dd_rescue 1.21:
  * Display warnings when using sparse writing.
* Sun Aug 22 2010 garloff@suse.de
- dd_rescue 1.20:
  * Update docs to document the overwrite disk with itself case
  * Also display progress bar if we know that the copy size due
    to -m.
* Sat Aug 21 2010 garloff@suse.de
- Really fix dd_rhelp to not break on new Summary line.
* Sat Aug 21 2010 garloff@suse.de
- Update to dd_rescue-1.19:
  * Fix 32bit screwup with display of total amount of date to copy
  * Support fallocate (using libfallocate) with -P (Prealloc)
  * More consistent use of ddrescue: (info): prefix (splice, Summary)
  * dd_rhelp adjusted for Summary change.
* Fri Aug 13 2010 garloff@suse.de
- Update to dd_rescue-1.18:
  * Change default for sync to -y0.
- Update to dd_rescue-1.17:
  * Display progress bar, percent completion and ETA
  * Better estimte current vs. avg speed
  * Exit on ENOSPC on target
  * Warn ONCE on EINVAL for fsync
- Update to dd_rescue-1.16:
  * Determine and display total amount of data to copy
* Fri Aug 13 2010 garloff@suse.de
- Adjust dd_rhelp to changes in dd_rescue.
* Fri Aug 13 2010 garloff@suse.de
- Update to dd_rescue-1.15:
  * Support for splice() to do zerocopy file copies
  * Better information on warnings and errors
  * Avoid repeated warning on fsync returning EINVAL
* Fri Aug 13 2010 garloff@suse.de
- Rename package to dd_rescue.
* Wed Aug 29 2007 garloff@suse.de
- Update to dd_rescue-1.14:
  * Fix bug with sparse (-a) mode that could lead to the target
    file not having the correct size.
* Mon Mar 19 2007 garloff@suse.de
- Update to dd_rescue-1.13:
  * Write full block of '0' for read errors and non-seekable
    output. (#255671)
* Tue Nov  7 2006 garloff@suse.de
- dd_rhelp: head/tail require -n option (thanks to Bryant Ling)
- dd_rhelp: Use -y0 if ddrescue is 1.12 or newer.
- dd_rhelp: Require bc.
* Sat Jul 29 2006 garloff@suse.de
- Update to dd_rescue-1.12:
  * Option -b: Log bad blocks to ASCII file
  * Option -y: Change fsync frequency (performance)
* Mon May 22 2006 schwab@suse.de
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Feb 21 2005 garloff@suse.de
- Add autoreconf to dd_rhelp.
* Mon Feb 14 2005 garloff@suse.de
- Update to dd_rescue-1.11:
  * O_DIRECT needs aligned buffers (Raymund Will)
  * Compile fix for systems without O_DIRECT
- Update to dd_rhelp 0.06
* Sun Aug 29 2004 garloff@suse.de
- Update to dd_rescue-1.10:
  * Support for non-seekable in-/output (pipes).
* Sun Aug 29 2004 garloff@suse.de
- Update to dd_rescue-1.04:
  * Include fix from Lab Valentin for dd_rhelp
  * Fix CPU load display overflow
  * Default soft block size now 64k instead of 16k
  * O_DIRECT supported (-d/-D)
  * option -p to copy permissions/owner/times
- Include dd_rhelp script (0.0.5) from Lab Valentin.
* Thu Jul 26 2001 garloff@suse.de
- Update to version 1.02:
  * Better handling of partially successful reads.
  * Don't loop on EFBIG when writing.
  * Avoid errno checking if not necessary.
* Mon Apr 30 2001 garloff@suse.de
- Bugfix release 1.01:
  * Don't loop trying to write to full partition (ENOSPC)
  * Fix compiler format warning (\%% -> %%%%)
  * Add lots of const qualifiers
  * Optimize block zero checking routine
* Fri Feb  9 2001 garloff@suse.de
- #include <stdarg.h> to fix compilation error on variadic fns
* Sat Dec  9 2000 nashif@suse.de
-  sorted
* Wed Aug 30 2000 garloff@suse.de
- Update to 1.00: Some preparation for supporting non-seekable
  in- or output. No support yet: Print warning and abort.
* Sat May 27 2000 garloff@suse.de
- Update to 0.99: Use stderr to print messages instead of stdout
- Prepare allowing - as stdin/stdout (but pread/pwrite() will fail)
- Fix spelling in README
- Use BuildRoot
* Fri Jan 14 2000 garloff@suse.de
- Fixed README.dd_rescue.
* Wed Oct 27 1999 garloff@suse.de
- Removed flushb. It belongs into util-linux.
* Wed Oct 20 1999 garloff@suse.de
- Fixed typo in help. (b <-> B)
* Fri Oct 15 1999 garloff@suse.de
- Initial release: 0.98.
